
__title__ = "lazydock"
__description__ = "Lazy Dock"
__url__ = "https://github.com/BHM-Bob/LazyDock"
__version__ = "0.0.1"
__build__ = "20240506_0"
__author__ = "BHM-Bob G"
__author_email__ = "bhmfly@foxmail.com"
__license__ = "MIT"